@@ -213,6 +213,7 @@ def _list_bgpvpns_result_filter_hook(query, filters):
 
 @db_api.CONTEXT_WRITER
 def _add_port_assoc_route_db_from_dict(context, route, port_association_id):
+    kwargs = {}
     if route['type'] == 'prefix':
         kwargs = {'prefix': route['prefix']}
     elif route['type'] == 'bgpvpn':
@@ -251,7 +252,7 @@ class BGPVPNPluginDb():
             query_hook=None,
             filter_hook=None,
             result_filters=_list_bgpvpns_result_filter_hook)
-        return super(BGPVPNPluginDb, cls).__new__(cls, *args, **kwargs)
+        return super().__new__(cls, *args, **kwargs)
 
     @db_api.CONTEXT_READER
     def _get_bgpvpns_for_tenant(self, session, tenant_id, fields):
@@ -306,21 +307,19 @@ class BGPVPNPluginDb():
         e_rt = utils.rtrd_list2str(bgpvpn['export_targets'])
         rd = utils.rtrd_list2str(bgpvpn.get('route_distinguishers', ''))
 
-        with db_api.CONTEXT_WRITER.using(context):
-            bgpvpn_db = BGPVPN(
-                id=uuidutils.generate_uuid(),
-                tenant_id=bgpvpn['tenant_id'],
-                name=bgpvpn['name'],
-                type=bgpvpn['type'],
-                route_targets=rt,
-                import_targets=i_rt,
-                export_targets=e_rt,
-                route_distinguishers=rd,
-                vni=bgpvpn.get(bgpvpn_vni_def.VNI),
-                local_pref=bgpvpn.get(bgpvpn_rc_def.LOCAL_PREF_KEY),
-            )
-            context.session.add(bgpvpn_db)
-
+        bgpvpn_db = BGPVPN(
+            id=uuidutils.generate_uuid(),
+            tenant_id=bgpvpn['tenant_id'],
+            name=bgpvpn['name'],
+            type=bgpvpn['type'],
+            route_targets=rt,
+            import_targets=i_rt,
+            export_targets=e_rt,
+            route_distinguishers=rd,
+            vni=bgpvpn.get(bgpvpn_vni_def.VNI),
+            local_pref=bgpvpn.get(bgpvpn_rc_def.LOCAL_PREF_KEY),
+        )
+        context.session.add(bgpvpn_db)
         return self._make_bgpvpn_dict(bgpvpn_db)
 
     @db_api.CONTEXT_READER
@@ -333,8 +332,8 @@ class BGPVPNPluginDb():
     def _get_bgpvpn(self, context, id):
         try:
             return model_query.get_by_id(context, BGPVPN, id)
-        except exc.NoResultFound:
-            raise bgpvpn_ext.BGPVPNNotFound(id=id)
+        except exc.NoResultFound as no_res:
+            raise bgpvpn_ext.BGPVPNNotFound(id=id) from no_res
 
     @db_api.CONTEXT_READER
     def get_bgpvpn(self, context, id, fields=None):
@@ -383,11 +382,11 @@ class BGPVPNPluginDb():
             return query.filter(BGPVPNNetAssociation.id == assoc_id,
                                 BGPVPNNetAssociation.bgpvpn_id == bgpvpn_id
                                 ).one()
-        except exc.NoResultFound:
-            raise bgpvpn_ext.BGPVPNNetAssocNotFound(id=assoc_id,
-                                                    bgpvpn_id=bgpvpn_id)
+        except exc.NoResultFound as no_res:
+            raise bgpvpn_ext.BGPVPNNetAssocNotFound(
+                id=assoc_id,
+                bgpvpn_id=bgpvpn_id) from no_res
 
-    @db_api.CONTEXT_WRITER
     def create_net_assoc(self, context, bgpvpn_id, net_assoc):
         try:
             with db_api.CONTEXT_WRITER.using(context):
@@ -397,13 +396,14 @@ class BGPVPNPluginDb():
                     network_id=net_assoc['network_id'])
                 context.session.add(net_assoc_db)
             return self._make_net_assoc_dict(net_assoc_db)
-        except db_exc.DBDuplicateEntry:
+        except db_exc.DBDuplicateEntry as db_dup_exc:
             LOG.warning("network %(net_id)s is already associated to "
                         "BGPVPN %(bgpvpn_id)s",
                         {'net_id': net_assoc['network_id'],
                          'bgpvpn_id': bgpvpn_id})
             raise bgpvpn_ext.BGPVPNNetAssocAlreadyExists(
-                bgpvpn_id=bgpvpn_id, net_id=net_assoc['network_id'])
+                bgpvpn_id=bgpvpn_id,
+                net_id=net_assoc['network_id']) from db_dup_exc
 
     @db_api.CONTEXT_READER
     def get_net_assoc(self, context, assoc_id, bgpvpn_id, fields=None):
@@ -430,7 +430,6 @@ class BGPVPNPluginDb():
         context.session.delete(net_assoc_db)
         return net_assoc
 
-    @db_api.CONTEXT_READER
     def _make_router_assoc_dict(self, router_assoc_db, fields=None):
         res = {'id': router_assoc_db['id'],
                'tenant_id': router_assoc_db['tenant_id'],
@@ -449,28 +448,30 @@ class BGPVPNPluginDb():
             return query.filter(BGPVPNRouterAssociation.id == assoc_id,
                                 BGPVPNRouterAssociation.bgpvpn_id == bgpvpn_id
                                 ).one()
-        except exc.NoResultFound:
-            raise bgpvpn_ext.BGPVPNRouterAssocNotFound(id=assoc_id,
-                                                       bgpvpn_id=bgpvpn_id)
+        except exc.NoResultFound as no_res_exc:
+            raise bgpvpn_ext.BGPVPNRouterAssocNotFound(
+                id=assoc_id,
+                bgpvpn_id=bgpvpn_id) from no_res_exc
 
     @db_api.CONTEXT_WRITER
     def create_router_assoc(self, context, bgpvpn_id, router_association):
         router_id = router_association['router_id']
         try:
-            with db_api.CONTEXT_WRITER.using(context):
-                router_assoc_db = BGPVPNRouterAssociation(
-                    tenant_id=router_association['tenant_id'],
-                    bgpvpn_id=bgpvpn_id,
-                    router_id=router_id)
-                context.session.add(router_assoc_db)
+            router_assoc_db = BGPVPNRouterAssociation(
+                tenant_id=router_association['tenant_id'],
+                bgpvpn_id=bgpvpn_id,
+                router_id=router_id)
+            context.session.add(router_assoc_db)
+            context.session.flush()
             return self._make_router_assoc_dict(router_assoc_db)
-        except db_exc.DBDuplicateEntry:
+        except db_exc.DBDuplicateEntry as db_dup_exc:
             LOG.warning("router %(router_id)s is already associated to "
                         "BGPVPN %(bgpvpn_id)s",
                         {'router_id': router_id,
                          'bgpvpn_id': bgpvpn_id})
             raise bgpvpn_ext.BGPVPNRouterAssocAlreadyExists(
-                bgpvpn_id=bgpvpn_id, router_id=router_association['router_id'])
+                bgpvpn_id=bgpvpn_id,
+                router_id=router_association['router_id']) from db_dup_exc
 
     @db_api.CONTEXT_READER
     def get_router_assoc(self, context, assoc_id, bgpvpn_id, fields=None):
@@ -525,11 +526,11 @@ class BGPVPNPluginDb():
             return query.filter(BGPVPNPortAssociation.id == assoc_id,
                                 BGPVPNPortAssociation.bgpvpn_id == bgpvpn_id
                                 ).one()
-        except exc.NoResultFound:
-            raise bgpvpn_rc_ext.BGPVPNPortAssocNotFound(id=assoc_id,
-                                                        bgpvpn_id=bgpvpn_id)
+        except exc.NoResultFound as no_res_exc:
+            raise bgpvpn_rc_ext.BGPVPNPortAssocNotFound(
+                id=assoc_id,
+                bgpvpn_id=bgpvpn_id) from no_res_exc
 
-    @db_api.CONTEXT_READER
     def create_port_assoc(self, context, bgpvpn_id, port_association):
         port_id = port_association['port_id']
         advertise_fixed_ips = port_association['advertise_fixed_ips']
@@ -541,18 +542,18 @@ class BGPVPNPluginDb():
                     port_id=port_id,
                     advertise_fixed_ips=advertise_fixed_ips)
                 context.session.add(port_assoc_db)
-        except db_exc.DBDuplicateEntry:
+        except db_exc.DBDuplicateEntry as db_dup_exc:
             LOG.warning(("port %(port_id)s is already associated to "
                          "BGPVPN %(bgpvpn_id)s"),
                         {'port_id': port_id,
                          'bgpvpn_id': bgpvpn_id})
             raise bgpvpn_rc_ext.BGPVPNPortAssocAlreadyExists(
-                bgpvpn_id=bgpvpn_id, port_id=port_association['port_id'])
+                bgpvpn_id=bgpvpn_id,
+                port_id=port_association['port_id']) from db_dup_exc
 
-        with db_api.CONTEXT_WRITER.using(context):
-            for route in port_association['routes']:
-                _add_port_assoc_route_db_from_dict(
-                    context, route, port_assoc_db.id)
+        for route in port_association['routes']:
+            _add_port_assoc_route_db_from_dict(
+                context, route, port_assoc_db.id)
         return self._make_port_assoc_dict(port_assoc_db)
 
     @db_api.CONTEXT_READER
@@ -570,7 +571,6 @@ class BGPVPNPluginDb():
             self._make_port_assoc_dict,
             filters, fields)
 
-    @db_api.CONTEXT_READER
     def update_port_assoc(self, context, assoc_id, bgpvpn_id, port_assoc):
         with db_api.CONTEXT_WRITER.using(context):
             port_assoc_db = self._get_port_assoc(context, assoc_id, bgpvpn_id)
