@@ -26,7 +26,7 @@ from neutron.api import extensions as api_extensions
 from neutron.db import servicetype_db as sdb
 from neutron import extensions as n_extensions
 from neutron.services import provider_configuration as pconfig
-from neutron.tests.unit.db import test_db_base_plugin_v2
+from neutron.tests.common import test_db_base_plugin_v2 as test_db_plugin
 from neutron.tests.unit.extensions import test_l3
 from neutron.tests.unit.extensions.test_l3 import TestL3NatServicePlugin
 from neutron_lib.api.definitions import bgpvpn as bgpvpn_def
@@ -42,8 +42,8 @@ _uuid = uuidutils.generate_uuid
 
 
 def http_client_error(req, res):
-    explanation = "Request '%s %s %s' failed: %s" % (req.method, req.url,
-                                                     req.body, res.body)
+    explanation = "Request '{} {} {}' failed: {}".format(req.method, req.url,
+                                                         req.body, res.body)
     return webob.exc.HTTPClientError(code=res.status_int,
                                      explanation=explanation)
 
@@ -54,10 +54,10 @@ class TestBgpvpnDriverWithVni(driver_api.BGPVPNDriverRC):
             bgpvpn_vni_def.ALIAS])
 
     def __init__(self, *args, **kwargs):
-        super(TestBgpvpnDriverWithVni, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
 
-class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
+class BgpvpnTestCaseMixin(test_db_plugin.NeutronDbPluginV2TestCase,
                           test_l3.L3NatTestCaseMixin):
 
     def setUp(self, service_provider=None, core_plugin=None):
@@ -105,7 +105,7 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
             {bgpvpn_def.ALIAS: plugin.BGPVPNPlugin(),
              'l3_plugin_name': TestL3NatServicePlugin()})
 
-        super(BgpvpnTestCaseMixin, self).setUp(
+        super().setUp(
             plugin=core_plugin,
             service_plugins=service_plugins,
             ext_mgr=ext_mgr)
@@ -139,7 +139,7 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
         else:
             req_data['bgpvpn'].update(kwargs)
         req = self.new_create_request(
-            'bgpvpn/bgpvpns', req_data, fmt=fmt)
+            'bgpvpn/bgpvpns', req_data, fmt=fmt, as_admin=True)
         res = req.get_response(self.ext_api)
         if res.status_int >= 400:
             raise http_client_error(req, res)
@@ -147,7 +147,7 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
         yield bgpvpn
         if do_delete:
             self._delete('bgpvpn/bgpvpns',
-                         bgpvpn['bgpvpn']['id'])
+                         bgpvpn['bgpvpn']['id'], as_admin=True)
 
     @contextlib.contextmanager
     def assoc_net(self, bgpvpn_id, net_id, do_disassociate=True):
@@ -159,7 +159,8 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
             data=data,
             fmt=fmt,
             id=bgpvpn_id,
-            subresource='network_associations')
+            subresource='network_associations',
+            as_admin=True)
         res = req.get_response(self.ext_api)
         if res.status_int >= 400:
             raise http_client_error(req, res)
@@ -171,7 +172,8 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
                 bgpvpn_id,
                 fmt=self.fmt,
                 subresource='network_associations',
-                sub_id=assoc['network_association']['id'])
+                sub_id=assoc['network_association']['id'],
+                as_admin=True)
             res = del_req.get_response(self.ext_api)
             if res.status_int >= 400:
                 raise http_client_error(del_req, res)
@@ -186,7 +188,8 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
             data=data,
             fmt=fmt,
             id=bgpvpn_id,
-            subresource='router_associations')
+            subresource='router_associations',
+            as_admin=True)
         res = req.get_response(self.ext_api)
         if res.status_int >= 400:
             raise http_client_error(req, res)
@@ -198,7 +201,8 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
                 bgpvpn_id,
                 fmt=self.fmt,
                 subresource='router_associations',
-                sub_id=assoc['router_association']['id'])
+                sub_id=assoc['router_association']['id'],
+                as_admin=True)
             res = del_req.get_response(self.ext_api)
             if res.status_int >= 400:
                 raise http_client_error(del_req, res)
@@ -214,7 +218,8 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
             data=data,
             fmt=fmt,
             id=bgpvpn_id,
-            subresource='port_associations')
+            subresource='port_associations',
+            as_admin=True)
         res = req.get_response(self.ext_api)
         if res.status_int >= 400:
             raise http_client_error(req, res)
@@ -226,7 +231,8 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
                 bgpvpn_id,
                 fmt=self.fmt,
                 subresource='port_associations',
-                sub_id=assoc['port_association']['id'])
+                sub_id=assoc['port_association']['id'],
+                as_admin=True)
             res = del_req.get_response(self.ext_api)
             if res.status_int >= 400:
                 raise http_client_error(del_req, res)
@@ -294,7 +300,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='network_associations')
+                    subresource='network_associations',
+                    as_admin=True)
                 res = bgpvpn_net_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPForbidden.code)
 
@@ -310,12 +317,13 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='network_associations')
+                    subresource='network_associations',
+                    as_admin=True)
                 res = bgpvpn_net_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPForbidden.code)
 
     def test_bgpvpn_router_assoc_create(self):
-        with self.router(tenant_id=self._tenant_id) as router,\
+        with self.router(tenant_id=self._tenant_id) as router, \
                 self.bgpvpn() as bgpvpn, \
                 mock.patch.object(
                     self.bgpvpn_plugin,
@@ -342,7 +350,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                                    bgpvpn_id,
                                    router_assoc['router_association']['id'],
                                    {'router_association':
-                                       {'advertise_extra_routes': False}}
+                                       {'advertise_extra_routes': False}},
+                                   as_admin=True
                                    )
             expected = {'router_association': {
                 'id': router_assoc['router_association']['id'],
@@ -362,7 +371,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=id,
-                subresource='router_associations')
+                subresource='router_associations',
+                as_admin=True)
             res = bgpvpn_router_req.get_response(self.ext_api)
             self.assertEqual(res.status_int, webob.exc.HTTPBadRequest.code)
 
@@ -377,7 +387,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=id,
-                subresource='router_associations')
+                subresource='router_associations',
+                as_admin=True)
             res = bgpvpn_router_req.get_response(self.ext_api)
             self.assertEqual(res.status_int, webob.exc.HTTPNotFound.code)
 
@@ -393,7 +404,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='router_associations')
+                    subresource='router_associations',
+                    as_admin=True)
                 res = bgpvpn_router_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPForbidden.code)
 
@@ -410,7 +422,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='router_associations')
+                    subresource='router_associations',
+                    as_admin=True)
                 res = bgpvpn_router_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPBadRequest.code)
 
@@ -426,12 +439,13 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='router_associations')
+                    subresource='router_associations',
+                    as_admin=True)
                 res = bgpvpn_router_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPForbidden.code)
 
     def test_router_net_combination(self):
-        with self.network() as net,\
+        with self.network() as net, \
                 self.bgpvpn() as bgpvpn, \
                 self.router(tenant_id=self._tenant_id) as router:
             self._test_router_net_combination_validation(
@@ -469,7 +483,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=router['id'],
-                subresource='add_router_interface')
+                subresource='add_router_interface',
+                as_admin=True)
             res = bgpvpn_rtr_intf_req.get_response(self.ext_api)
             if res.status_int >= 400:
                 raise http_client_error(bgpvpn_rtr_intf_req, res)
@@ -509,7 +524,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=router['id'],
-                subresource='add_router_interface')
+                subresource='add_router_interface',
+                as_admin=True)
             res = bgpvpn_rtr_intf_req.get_response(self.ext_api)
             if res.status_int >= 400:
                 raise http_client_error(bgpvpn_rtr_intf_req, res)
@@ -526,11 +542,11 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
             self.assertEqual(res.status_int, webob.exc.HTTPBadRequest.code)
 
     def test_attach_subnet_to_router_both_attached_to_bgpvpn(self):
-        with self.network() as net,\
-                self.bgpvpn() as bgpvpn,\
-                self.router(tenant_id=self._tenant_id) as router,\
-                self.subnet(network={'network': net['network']}) as subnet,\
-                self.assoc_net(bgpvpn['bgpvpn']['id'], net['network']['id']),\
+        with self.network() as net, \
+                self.bgpvpn() as bgpvpn, \
+                self.router(tenant_id=self._tenant_id) as router, \
+                self.subnet(network={'network': net['network']}) as subnet, \
+                self.assoc_net(bgpvpn['bgpvpn']['id'], net['network']['id']), \
                 self.assoc_router(bgpvpn['bgpvpn']['id'],
                                   router['router']['id']):
             # Attach subnet to router
@@ -540,17 +556,18 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=router['router']['id'],
-                subresource='add_router_interface')
+                subresource='add_router_interface',
+                as_admin=True)
             res = bgpvpn_rtr_intf_req.get_response(self.ext_api)
             self.assertEqual(res.status_int, webob.exc.HTTPConflict.code)
 
     def test_attach_port_to_router_both_attached_to_bgpvpn(self):
-        with self.network() as net,\
-                self.bgpvpn() as bgpvpn,\
-                self.router(tenant_id=self._tenant_id) as router,\
-                self.subnet(network={'network': net['network']}) as subnet,\
-                self.port(subnet={'subnet': subnet['subnet']}) as port,\
-                self.assoc_net(bgpvpn['bgpvpn']['id'], net['network']['id']),\
+        with self.network() as net, \
+                self.bgpvpn() as bgpvpn, \
+                self.router(tenant_id=self._tenant_id) as router, \
+                self.subnet(network={'network': net['network']}) as subnet, \
+                self.port(subnet={'subnet': subnet['subnet']}) as port, \
+                self.assoc_net(bgpvpn['bgpvpn']['id'], net['network']['id']), \
                 self.assoc_router(bgpvpn['bgpvpn']['id'],
                                   router['router']['id']):
             # Attach subnet to router
@@ -560,7 +577,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=router['router']['id'],
-                subresource='add_router_interface')
+                subresource='add_router_interface',
+                as_admin=True)
             res = bgpvpn_rtr_intf_req.get_response(self.ext_api)
             self.assertEqual(res.status_int, webob.exc.HTTPConflict.code)
 
@@ -581,7 +599,7 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                                 routes=[{
                                     'type': 'prefix',
                                     'prefix': '12.1.3.0/24',
-                                    }]):
+                                }]):
             mock_validate.assert_called_once_with(
                 mock.ANY, port['port']['id'])
 
@@ -601,7 +619,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=bgpvpn['bgpvpn']['id'],
-                subresource='port_associations')
+                subresource='port_associations',
+                as_admin=True)
             res = bgpvpn_net_req.get_response(self.ext_api)
             self.assertEqual(res.status_int, webob.exc.HTTPBadRequest.code)
             return res.body
@@ -618,8 +637,7 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     'routes': [{
                         'type': 'bgpvpn',
                         'bgpvpn_id': '3aff9b6b-387b-4ffd-a9ff-a4bdffb349ff'
-                        }]
-                    }}
+                    }]}}
 
             bgpvpn_net_req = self.new_create_request(
                 'bgpvpn/bgpvpns',
@@ -645,15 +663,15 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     'routes': [{
                         'type': 'bgpvpn',
                         'bgpvpn_id': bgpvpn_other['bgpvpn']['id']
-                        }]
-                    }}
+                    }]}}
 
             bgpvpn_net_req = self.new_create_request(
                 'bgpvpn/bgpvpns',
                 data=data,
                 fmt=self.fmt,
                 id=bgpvpn['bgpvpn']['id'],
-                subresource='port_associations')
+                subresource='port_associations',
+                as_admin=True)
             res = bgpvpn_net_req.get_response(self.ext_api)
             self.assertEqual(res.status_int, webob.exc.HTTPBadRequest.code)
             self.assertIn("bgpvpn specified in route does not belong to "
@@ -700,7 +718,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='port_associations')
+                    subresource='port_associations',
+                    as_admin=True)
                 res = bgpvpn_port_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPForbidden.code)
 
@@ -716,7 +735,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='port_associations')
+                    subresource='port_associations',
+                    as_admin=True)
                 res = bgpvpn_port_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPForbidden.code)
 
@@ -735,7 +755,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
 
             self._update('bgpvpn/bgpvpns/%s/port_associations' % bgpvpn_id,
                          port_assoc['port_association']['id'],
-                         {'port_association': {'advertise_fixed_ips': False}}
+                         {'port_association': {'advertise_fixed_ips': False}},
+                         as_admin=True
                          )
 
             # one call for create, one call for update
@@ -758,10 +779,10 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     'routes': [{
                         'type': 'bgpvpn',
                         'bgpvpn_id': bgpvpn_other['bgpvpn']['id']
-                        }]
-                    }
-                 },
-                port_assoc['port_association']['id']
+                    }]
+                }},
+                port_assoc['port_association']['id'],
+                as_admin=True
             )
 
             res = req.get_response(self.ext_api)
@@ -788,10 +809,10 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     'routes': [{
                         'type': 'bgpvpn',
                         'bgpvpn_id': bgpvpn_l3['bgpvpn']['id']
-                        }]
-                    }
-                 },
-                port_assoc['port_association']['id']
+                    }]
+                }},
+                port_assoc['port_association']['id'],
+                as_admin=True
             )
 
             res = req.get_response(self.ext_api)
@@ -804,7 +825,7 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
 class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
 
     def setUp(self):
-        super(TestBGPVPNServiceDriverDB, self).setUp()
+        super().setUp()
 
     def _raise_bgpvpn_driver_precommit_exc(self, *args, **kwargs):
         raise extensions.bgpvpn.BGPVPNDriverError(method='precommit method')
@@ -834,7 +855,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                                new=self._raise_bgpvpn_driver_precommit_exc):
             # Assert that an error is returned to the client
             bgpvpn_req = self.new_create_request(
-                'bgpvpn/bgpvpns', self.bgpvpn_data)
+                'bgpvpn/bgpvpns', self.bgpvpn_data, as_admin=True)
             res = bgpvpn_req.get_response(self.ext_api)
             self.assertEqual(webob.exc.HTTPError.code,
                              res.status_int)
@@ -852,12 +873,19 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                                   'delete_bgpvpn_precommit',
                                   new=self._raise_bgpvpn_driver_precommit_exc):
             bgpvpn_req = self.new_delete_request('bgpvpn/bgpvpns',
-                                                 bgpvpn['bgpvpn']['id'])
+                                                 bgpvpn['bgpvpn']['id'],
+                                                 as_admin=True)
             res = bgpvpn_req.get_response(self.ext_api)
             self.assertEqual(webob.exc.HTTPError.code,
                              res.status_int)
             # Assert that existing bgpvpn remains
             list = self._list('bgpvpn/bgpvpns', fmt='json')
+            bgpvpn['bgpvpn'].pop('import_targets')
+            bgpvpn['bgpvpn'].pop('project_id')
+            bgpvpn['bgpvpn'].pop('tenant_id')
+            bgpvpn['bgpvpn'].pop('route_distinguishers')
+            bgpvpn['bgpvpn'].pop('route_targets')
+            bgpvpn['bgpvpn'].pop('export_targets')
             self.assertEqual([bgpvpn['bgpvpn']], list['bgpvpns'])
 
     @mock.patch.object(driver_api.BGPVPNDriver,
@@ -869,7 +897,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                 mock.patch.object(bgpvpn_db.BGPVPNPluginDb, 'get_bgpvpn',
                                   return_value=self.converted_data):
             self._delete('bgpvpn/bgpvpns',
-                         bgpvpn['bgpvpn']['id'])
+                         bgpvpn['bgpvpn']['id'], as_admin=True)
             mock_delete_db.assert_called_once_with(mock.ANY,
                                                    bgpvpn['bgpvpn']['id'])
             mock_delete_postcommit.assert_called_once_with(mock.ANY,
@@ -878,7 +906,8 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
     @mock.patch.object(bgpvpn_db.BGPVPNPluginDb, 'get_bgpvpn')
     def test_get_bgpvpn(self, mock_get_db):
         with self.bgpvpn() as bgpvpn:
-            self._show('bgpvpn/bgpvpns', bgpvpn['bgpvpn']['id'])
+            self._show('bgpvpn/bgpvpns', bgpvpn['bgpvpn']['id'],
+                       as_admin=True)
             mock_get_db.assert_called_once_with(mock.ANY,
                                                 bgpvpn['bgpvpn']['id'],
                                                 mock.ANY)
@@ -928,7 +957,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
             data = {"bgpvpn": {"name": new_bgpvpn['name']}}
             self._update('bgpvpn/bgpvpns',
                          bgpvpn['bgpvpn']['id'],
-                         data)
+                         data, as_admin=True)
 
             mock_update_db.assert_called_once_with(
                 mock.ANY, bgpvpn['bgpvpn']['id'], data['bgpvpn'])
@@ -946,7 +975,8 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
             self._update('bgpvpn/bgpvpns',
                          bgpvpn['bgpvpn']['id'],
                          new_data,
-                         expected_code=webob.exc.HTTPError.code)
+                         expected_code=webob.exc.HTTPError.code,
+                         as_admin=True)
             show_bgpvpn = self._show('bgpvpn/bgpvpns',
                                      bgpvpn['bgpvpn']['id'])
             self.assertEqual(self.bgpvpn_data['bgpvpn']['name'],
@@ -998,7 +1028,8 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=fmt,
                 id=bgpvpn['bgpvpn']['id'],
-                subresource='network_associations')
+                subresource='network_associations',
+                as_admin=True)
             res = bgpvpn_net_req.get_response(self.ext_api)
             # Assert that driver failure returns an error
             self.assertEqual(webob.exc.HTTPError.code,
@@ -1018,7 +1049,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                     assoc_id = assoc['network_association']['id']
                     res = 'bgpvpn/bgpvpns/' + bgpvpn_id + \
                           '/network_associations'
-                    self._show(res, assoc_id)
+                    self._show(res, assoc_id, as_admin=True)
                     mock_get_db.assert_called_once_with(mock.ANY,
                                                         assoc_id,
                                                         bgpvpn_id,
@@ -1058,6 +1089,12 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                     # Assert that existing bgpvpn and net-assoc remains
                     list = self._list('bgpvpn/bgpvpns', fmt='json')
                     bgpvpn['bgpvpn']['networks'] = [net_assoc['network_id']]
+                    bgpvpn['bgpvpn'].pop('import_targets')
+                    bgpvpn['bgpvpn'].pop('project_id')
+                    bgpvpn['bgpvpn'].pop('tenant_id')
+                    bgpvpn['bgpvpn'].pop('route_distinguishers')
+                    bgpvpn['bgpvpn'].pop('route_targets')
+                    bgpvpn['bgpvpn'].pop('export_targets')
                     self.assertEqual([bgpvpn['bgpvpn']], list['bgpvpns'])
 
     @mock.patch.object(driver_api.BGPVPNDriver,
@@ -1127,7 +1164,8 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=fmt,
                 id=bgpvpn['bgpvpn']['id'],
-                subresource='router_associations')
+                subresource='router_associations',
+                as_admin=True)
             res = bgpvpn_router_req.get_response(self.ext_api)
             # Assert that driver failure returns an error
             self.assertEqual(webob.exc.HTTPError.code,
@@ -1141,13 +1179,14 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
     def test_get_bgpvpn_router_assoc(self, mock_get_db):
         with self.bgpvpn() as bgpvpn:
             bgpvpn_id = bgpvpn['bgpvpn']['id']
-            with self.router(tenant_id=self._tenant_id) as router:
+            with self.router(tenant_id=self._tenant_id,
+                             as_admin=True) as router:
                 router_id = router['router']['id']
                 with self.assoc_router(bgpvpn_id, router_id) as assoc:
                     assoc_id = assoc['router_association']['id']
                     res = 'bgpvpn/bgpvpns/' + bgpvpn_id + \
                           '/router_associations'
-                    self._show(res, assoc_id)
+                    self._show(res, assoc_id, as_admin=True)
                     mock_get_db.assert_called_once_with(mock.ANY,
                                                         assoc_id,
                                                         bgpvpn_id,
@@ -1187,6 +1226,12 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                     # Assert that existing bgpvpn and router-assoc remains
                     list = self._list('bgpvpn/bgpvpns', fmt='json')
                     bgpvpn['bgpvpn']['routers'] = [router_assoc['router_id']]
+                    bgpvpn['bgpvpn'].pop('import_targets')
+                    bgpvpn['bgpvpn'].pop('project_id')
+                    bgpvpn['bgpvpn'].pop('tenant_id')
+                    bgpvpn['bgpvpn'].pop('route_distinguishers')
+                    bgpvpn['bgpvpn'].pop('route_targets')
+                    bgpvpn['bgpvpn'].pop('export_targets')
                     self.assertEqual([bgpvpn['bgpvpn']], list['bgpvpns'])
 
     @mock.patch.object(driver_api.BGPVPNDriver,
@@ -1223,8 +1268,8 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                                       mock_pre_commit,
                                       mock_post_commit):
         with self.bgpvpn() as bgpvpn, \
-                self.network() as net,\
-                self.subnet(network={'network': net['network']}) as subnet,\
+                self.network() as net, \
+                self.subnet(network={'network': net['network']}) as subnet, \
                 self.port(subnet={'subnet': subnet['subnet']},
                           tenant_id=self._tenant_id) as port:
             bgpvpn_id = bgpvpn['bgpvpn']['id']
@@ -1263,7 +1308,8 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=fmt,
                 id=bgpvpn['bgpvpn']['id'],
-                subresource='port_associations')
+                subresource='port_associations',
+                as_admin=True)
             res = bgpvpn_port_req.get_response(self.ext_api)
             # Assert that driver failure returns an error
             self.assertEqual(webob.exc.HTTPError.code,
@@ -1276,14 +1322,14 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
     @mock.patch.object(bgpvpn_db.BGPVPNPluginDb, 'get_port_assoc')
     def test_get_bgpvpn_port_assoc(self, mock_get_db):
         with self.bgpvpn() as bgpvpn, \
-                self.port(tenant_id=self._tenant_id) as port, \
+                self.port(tenant_id=self._tenant_id, is_admin=True) as port, \
                 self.assoc_port(bgpvpn['bgpvpn']['id'],
                                 port['port']['id']) as assoc:
             bgpvpn_id = bgpvpn['bgpvpn']['id']
             assoc_id = assoc['port_association']['id']
             res = 'bgpvpn/bgpvpns/' + bgpvpn_id + \
                   '/port_associations'
-            self._show(res, assoc_id)
+            self._show(res, assoc_id, as_admin=True)
             mock_get_db.assert_called_once_with(mock.ANY,
                                                 assoc_id,
                                                 bgpvpn_id,
@@ -1309,7 +1355,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
     def test_delete_bgpvpn_port_assoc_precommit_fails(self, mock_db_del,
                                                       mock_precommit):
         with self.bgpvpn() as bgpvpn, \
-                self.port(tenant_id=self._tenant_id) as port, \
+                self.port(tenant_id=self._tenant_id, is_admin=True) as port, \
                 self.assoc_port(bgpvpn['bgpvpn']['id'],
                                 port['port']['id']) as assoc:
             port_id = port['port']['id']
@@ -1324,6 +1370,12 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
             # Assert that existing bgpvpn and port-assoc remains
             list = self._list('bgpvpn/bgpvpns', fmt='json')
             bgpvpn['bgpvpn']['ports'] = [port_assoc['port_id']]
+            bgpvpn['bgpvpn'].pop('import_targets')
+            bgpvpn['bgpvpn'].pop('project_id')
+            bgpvpn['bgpvpn'].pop('tenant_id')
+            bgpvpn['bgpvpn'].pop('route_distinguishers')
+            bgpvpn['bgpvpn'].pop('route_targets')
+            bgpvpn['bgpvpn'].pop('export_targets')
             self.assertEqual([bgpvpn['bgpvpn']], list['bgpvpns'])
 
     @mock.patch.object(driver_api.BGPVPNDriverRC,
@@ -1352,7 +1404,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
             data = {"port_association": changed}
             self._update('bgpvpn/bgpvpns/%s/port_associations' % bgpvpn_id,
                          assoc['port_association']['id'],
-                         data)
+                         data, as_admin=True)
 
             mock_db_update.assert_called_once_with(mock.ANY,
                                                    assoc_id,
@@ -1362,12 +1414,12 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                 mock.ANY,
                 assoc['port_association'],
                 new_port_assoc['port_association']
-                )
+            )
             mock_postcommit.assert_called_once_with(
                 mock.ANY,
                 assoc['port_association'],
                 new_port_assoc['port_association']
-                )
+            )
 
     @mock.patch.object(driver_api.BGPVPNDriverRC,
                        'delete_port_assoc_precommit')
